==> nextcloud-25.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/circles/l10n/pl.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Kręgi",
    "Circles' files" : "Pliki kręgu",
    "Select circles to filter by" : "Aby użyć filtru wybierz kręgi",
    "No circles found" : "Nie znaleziono żadnych kręgów",
    "Please select circles to filter by" : "Aby użyć filtru, należy wybrać kręgi",
    "No files found for the selected circles" : "Nie znaleziono plików dla wybranych kręgów",
    "You created the circle {circle}" : "Utworzyłeś krąg {circle}",
    "{author} created the circle {circle}" : "{author} utworzył krąg {circle}",
    "You deleted {circle}" : "Usunąłeś {circle}",
    "{author} deleted {circle}" : "{author} usunął {circle}",
    "You linked {group} to {circle}" : "Podłączyłeś {group} do kręgu {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} została podłączona do kręgu {circle} przez {author}",
    "You unlinked {group} from {circle}" : "Odłączyłeś {group} z kręgu {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} została odłączona z kręgu {circle} przez {author}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Zmieniłeś poziom podłączonej grupy {group} w kręgu {circle} do %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} zmienił poziom podłączonej grupy {group} w kręgu {circle} do %1$s",
    "You sent a request to link {circle} with {remote}" : "Wysłałeś prośbę o podłączenie kręgu {circle} z {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} wysłał prośbę o podłączenie kręgu {circle} z {remote}",
    "{remote} requested a link with {circle}" : "{remote} poprosił o podłączenie z kręgiem {circle}",
    "The request to link {circle} with {remote} has been rejected" : "Prośba o podłączenie kręgu {circle} z {remote} rozstała odrzucona",
    "The request to link {remote} with {circle} has been canceled remotely" : "Prośba {remote} o podłączenie z kręgiem {circle} została zdalnie anulowana",
    "The request to link {circle} with {remote} has been accepted" : "Prośba o podłączenie kręgu {circle} z {remote} rozstała zaakceptowana",
    "You dismissed the request to link {remote} with {circle}" : "Odrzuciłeś prośbę o podłączenie {remote} z kręgiem {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} odrzucił prośbę o podłączenie {remote} z kręgiem {circle}",
    "You canceled the request to link {circle} with {remote}" : "Anulowałeś prośbę o podłączenie kręgu {circle} z {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} anulował prośbę o podłączenie kręgu {circle} z {remote}",
    "You accepted the request to link {remote} with {circle}" : "Zaakceptowałeś prośbę o podłączenie {remote} z kręgiem {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} zaakceprował podłączenie {remote} z kręgiem {circle}",
    "A link between {circle} and {remote} is now up and running" : "Połączenie między {circle} a {remote} jest teraz aktywne i uruchomione",
    "The link between {circle} and {remote} has been shutdown remotely" : "Połączenie między {circle} a {remote} zostało rozłączone zdalnie",
    "You closed the link between {circle} and {remote}" : "Zamknąłeś połączenie między {circle} a {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} zamknął połączenie między {circle} a {remote}",
    "You joined {circle}" : "Dołączyłeś do {circle}",
    "{member} joined {circle}" : "{member} dołączył do {circle}",
    "You accepted the invitation to join {circle}" : "Zaakceptowałeś zaproszenie o dołączenie do {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} zaakceptował zaproszenie o dołączenie do {circle}",
    "You added {member} as member to {circle}" : "Dodałeś {member} do członków {circle}",
    "You have been added as member to {circle} by {author}" : "Zostałeś dodany jako członek do kręgu {circle} przez {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} został dodany do kręgu {circle} przez {author}",
    "You added {external} to {circle}" : "Dodałeś {external} do kręgu {circle}",
    "{external} has been added to {circle} by {author}" : "{external} został dodany do kręgu {circle} przez {author}",
    "You accepted {member}'s request to join {circle}" : "Zaakceptowałeś prośbę o dołączenie {member} do {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Twoja prośba o dołączenie do {circle} została zaakceptowana przez {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Prośba {member} o dołączenie do {circle} została zaakceptowana przez {author}",
    "You left {circle}" : "Opuściłeś {circle}",
    "{member} left {circle}" : "{member} opuścił {circle}",
    "You declined the invitation to join {circle}" : "Odrzuciłeś zaproszenie o dołączenie do kręgu {circle}",
    "{member} declined an invitation to join {circle}" : "{member} odrzucił zaproszenie o dołączenie do kręgu {circle}",
    "You cancelled your request to join {circle}" : "Anulowałeś prośbę o dołączenie do kręgu {circle}",
    "{member} cancelled his request to join {circle}" : "{member} anulował swoją prośbę o dołączenie do {circle}",
    "You removed {member} from {circle}" : "Usunąłeś {member} z {circle}",
    "You have been removed from {circle} by {author}" : "Zostałeś usunięty z kręgu {circle} przez {author}",
    "{member} has been removed from {circle} by {author}" : "{member} został usunięty z kręgu {circle} przez {author}",
    "You removed {external} from {circle}" : "Usunąłeś {external} z kręgu {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} został usunięty z kręgu {circle} przez {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Anulowałeś zaproszenie {member} o dołączenie do kręgu {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Twoje zaproszenie o dołączenie do kręgu {circle} zostało anulowane przez {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} anulował zaproszenie {member} o dołączenie do kręgu {circle}",
    "You dismissed {member}'s request to join {circle}" : "Odrzuciłeś prośbę {member} o dołączenie do kręgu {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Twoja prośba o dołączenie do kręgu {circle} została odrzucona przez {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Prośba {member} o dołączenie do kręgu {circle} została odrzucona przez {author}",
    "You invited {member} to join {circle}" : "Zaprosiłeś {member} do dołączenia do kręgu {circle}",
    "You have been invited to join {circle} by {author}" : "Zostałeś zaproszony do dołączenia do kręgu {circle} przez {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} został zaproszony do dołączenia do kręgu {circle} przez {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Zmieniłeś poziom użytkownika {member} w {circle} na %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} zmienił Twój poziom {circle} na %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} zmienił poziom {member} w {circle} na %1$s",
    "You sent a request to join {circle}" : "Wysłałeś prośbę o dołączenie do kręgu {circle}",
    "{member} sent a request to join {circle}" : "{member} wysłał prośbę o dołączenie do kręgu {circle}",
    "You are the new owner of {circle}" : "Jesteś nowym właścicielem {circle}",
    "{member} is the new owner of {circle}" : "{member} został nowym właścicielem {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "O wydarzeniach w <strong>Kręgu</strong>, którego jesteś członkiem",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Każde ważne wydarzenie w <strong>Kręgu</strong>, który moderujesz",
    "On global events happening in any <strong>Circle</strong>" : "O wydarzeniach globalnych w dowolnym <strong>Kręgu</strong>",
    "Single" : "Jednoosobowy",
    "Personal" : "Osobisty",
    "System" : "System",
    "Visible" : "Widoczny",
    "Open" : "Otwórz",
    "Invite" : "Zaproś",
    "Join Request" : "Prośba o dołączenie",
    "Friends" : "Przyjaciele",
    "Password Protected" : "Zabezpieczone hasłem",
    "No Owner" : "Brak właściciela",
    "Hidden" : "Ukryty",
    "Backend" : "Zaplecze",
    "Local" : "Lokalny",
    "Root" : "Root",
    "Circle Invite" : "Zaprosić do kręgu",
    "Federated" : "Sfederowany",
    "Mount point" : "Punkt montowania",
    "Nextcloud Group" : "Grupa Nextcloud",
    "Email Address" : "Adres e-mail",
    "Contact" : "Kontakt",
    "Circle" : "Krąg",
    "Nextcloud App" : "Aplikacja Nextcloud",
    "Member" : "Członek",
    "Moderator" : "Moderator",
    "Admin" : "Administrator",
    "Owner" : "Właściciel",
    "%s shared »%s« with you." : "%s udostępnił Tobie »%s«.",
    "%s shared »%s« with \"%s\"." : "%s udostępnił »%s« z \"%s\".",
    "%s on %s" : "%s na %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s udostępnił »%2$s«.\nPowinieneś już otrzymać oddzielną wiadomość zawierającą link do udostępnionego zasobu.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s udostępnił »%2$s«. Powinieneś już otrzymać oddzielną wiadomość zawierającą link do udostępnionego zasobu.",
    "Password to access »%1$s« shared to you by %2$s" : "Hasło dostępu do »%1$s« udostępnionego przez %2$s",
    "Password to access »%s«" : "Hasło dostępu do »%s«",
    "It is protected with the following password:" : "Zasób chroniony jest następującym hasłem:",
    "%1$s via %2$s" : "%1$s przez %2$s",
    "Click the button below to open it." : "Kliknij przycisk poniżej, aby go otworzyć.",
    "Open »%s«" : "Otwórz »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s udostępnił Tobie wiele plików.\nPowinieneś otrzymać osobną wiadomość e-mail z linkiem do nich.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s udostępnił Tobie wiele plików. Powinieneś otrzymać osobną wiadomość e-mail z linkiem do nich.",
    "Password to access files shared to you by %1$s" : "Hasło dostępu do plików udostępnionych Tobie przez %1$s",
    "Password to access files" : "Hasło dostępu do plików",
    "%s shared multiple files with \"%s\"." : "%s udostępnił wiele plików z \"%s\".",
    "%s shared multiple files with you." : "%s udostępnił Tobie wiele plików.",
    "Boot up" : "Uruchom",
    "Initialisation Nextcloud" : "Inicjalizacja Nextcloud",
    "Initialisation Circles App" : "Inicjalizacja aplikacji Kręgi",
    "Fresh installation status" : "Stan nowej instalacji",
    "Building Local Database" : "Tworzenie lokalnej bazy danych",
    "Testing Basic Circle Creation" : "Testowanie tworzenia podstawowego kręgu",
    "Adding local users and moderators" : "Dodawanie lokalnych użytkowników i moderatorów",
    "Circle not found" : "Krąg nie został znaleziony",
    "Circle not found " : "Krąg nie został znaleziony ",
    "A circle with that name exists" : "Krąg o takiej nazwie istnieje",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Nie możesz używać aplikacji Kręgi, dopóki administrator nie zaakceptuje co najmniej jednego typu kręgów",
    "This member does not exist" : "Ten członek nie istnieje",
    "Federated link not found" : "Nie znaleziono linku federacyjnego",
    "This feature is not available for personal circles" : "Ta funkcja nie jest dostępna dla kręgów osobistych",
    "The circle is not federated" : "Krąg nie należy do federacji",
    "You cannot join this circle" : "Nie możesz dołączyć do tego kręgu",
    "This member is not a moderator" : "Ten członek nie jest moderatorem",
    "Insufficient privileges" : "Niewystarczające uprawnienia",
    "This member is the owner of the circle" : "Ten członek jest właścicielem kręgu",
    "Level cannot be changed for this type of member" : "Nie można zmienić poziomu dla tego typu członka",
    "You are already a member of this circle" : "Już jesteś członkiem tego kręgu",
    "You have been blocked from this circle" : "Zostałeś zablokowany w tym kręgu",
    "%s (Circle owned by %s)" : "%s (Okrąg należący do %s)",
    "You are now a member of the Circle \"%2$s\"" : "Jesteś teraz członkiem Kręgu \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Zostałeś zaproszony przez %1$s do Kręgu \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s wysłał prośbę o członkostwo w Kręgu \"%2$s\"",
    "Accept" : "Akceptuj",
    "Refuse" : "Odrzuć",
    "Leave the circle" : "Opuść krąg",
    "%s" : "%s",
    "Personal Circle" : "Krąg Osobisty",
    "%s owned by %s" : "%s należący do %s",
    "You need a specify a type of circle" : "Należy podać rodzaj kręgu",
    "This member is not the owner of the circle" : "Ten członek nie jest właścicielem kręgu",
    "This member is not an admin of the circle" : "Ten użytkownik nie jest administratorem kręgu",
    "Group contains too many members" : "Grupa zawiera zbyt wielu członków",
    "This group does not exist" : "Ta grupa nie istnieje",
    "This group is already linked to the circle" : "Grupa jest już połączona z tym kręgiem",
    "You cannot edit level in a personal circle" : "Nie można edytować poziomów w kręgach osobistych",
    "Group cannot be set as owner of a circle" : "Nie można ustawić grupy jako właściciela kręgu",
    "now" : "teraz",
    "Email format is not valid" : "Adres e-mail jest nieprawidłowy",
    "This contact is not available" : "Kontakt jest niedostępny",
    "You have no permission to create a new circle" : "Nie masz uprawnień do utworzenia nowego kręgu",
    "%s shared a file with \"%s\"." : "%s udostępnił plik z \"%s\".",
    "%s shared a file with you." : "%s udostępnił Tobie plik.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s udostępnił Tobie niektóre treści.\nPowinieneś już otrzymać osobną wiadomość e-mail z linkiem, aby uzyskać do niego dostęp.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s udostępnił Tobie niektóre treści. Powinieneś już otrzymać osobną wiadomość e-mail z linkiem, aby uzyskać do niego dostęp.",
    "Password to access content shared with you by %1$s" : "Hasło dostępu do treści udostępnionej Tobie przez %1$s",
    "Password to access content" : "Hasło dostępu do treści",
    "This item is already shared with this circle" : "Element jest już udostępniony w tym kręgu",
    "Could not find share" : "Nie można znaleźć udostępnienia",
    "Bring cloud-users closer together." : "Integruje użytkowników chmury.",
    "No files in here" : "Brak plików tutaj",
    "No entries found in this folder" : "Brak wpisów w tym katalogu",
    "Name" : "Nazwa",
    "Size" : "Rozmiar",
    "Modified" : "Zmodyfikowano",
    "Nextcloud User" : "Użytkownik Nextcloud",
    "This user is already a member of the circle" : "Użytkownik jest już członkiem tego kręgu",
    "The user is already a member of this circle" : "Użytkownik jest już członkiem tego kręgu",
    "The user has already been invited into this circle" : "Użytkownik został już zaproszony do tego kręgu",
    "This user does not exist" : "Ten użytkownik nie istnieje",
    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "Kręgi umożliwiają użytkownikom tworzenie własnych grup użytkowników/współpracowników/przyjaciół.\nGrupy użytkowników (lub \"kręgi\") mogą być następnie używane przez dowolną inną aplikację do celów udostępniania."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-32.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/circles/l10n/pl.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Zespoły",
    "You created the team {circle}" : "Utworzyłeś zespół {circle}",
    "{author} created the team {circle}" : "{author} utworzył zespół {circle}",
    "You deleted {circle}" : "Usunąłeś {circle}",
    "{author} deleted {circle}" : "{author} usunął {circle}",
    "You made {member} join {circle}" : "Zmusiłeś {member} do przyłączenia się do {circle}",
    "{author} made {member} join {circle}" : "{author} zmusił {member} do przyłączenia się do {circle}",
    "You added team {member} as member to {circle}" : "Dodałeś zespół {member} jako członka do {circle}",
    "{author} added team {member} as member to {circle}" : "{author} dodał zespół {member} jako członka do {circle}",
    "You made {member} leave {circle}" : "Zmusiłeś {member} do opuszczenia {circle}",
    "{author} made {member} leave {circle}" : "{author} zmusił {member} do opuszczenia {circle}",
    "You removed {member} from {circle}" : "Usunąłeś {member} z {circle}",
    "{author} removed {member} from {circle}" : "{author} usunął {member} z {circle}",
    "You joined {circle}" : "Dołączyłeś do {circle}",
    "{member} joined {circle}" : "{member} dołączył do {circle}",
    "You accepted the invitation to join {circle}" : "Zaakceptowałeś zaproszenie o dołączenie do {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} zaakceptował zaproszenie o dołączenie do {circle}",
    "You added {member} as member to {circle}" : "Dodałeś {member} do członków {circle}",
    "You have been added as member to {circle} by {author}" : "Zostałeś dodany jako członek do kręgu {circle} przez {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} został dodany do kręgu {circle} przez {author}",
    "You added {external} to {circle}" : "Dodałeś {external} do kręgu {circle}",
    "{external} has been added to {circle} by {author}" : "{external} został dodany do kręgu {circle} przez {author}",
    "You accepted {member}'s request to join {circle}" : "Zaakceptowałeś prośbę o dołączenie {member} do {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Twoja prośba o dołączenie do {circle} została zaakceptowana przez {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Prośba {member} o dołączenie do {circle} została zaakceptowana przez {author}",
    "You left {circle}" : "Opuściłeś {circle}",
    "{member} left {circle}" : "{member} opuścił {circle}",
    "You declined the invitation to join {circle}" : "Odrzuciłeś zaproszenie o dołączenie do kręgu {circle}",
    "{member} declined an invitation to join {circle}" : "{member} odrzucił zaproszenie o dołączenie do kręgu {circle}",
    "You cancelled your request to join {circle}" : "Anulowałeś prośbę o dołączenie do kręgu {circle}",
    "{member} cancelled a request to join {circle}" : "{member} anulował prośbę o dołączenie do {circle}",
    "You have been removed from {circle} by {author}" : "Zostałeś usunięty z kręgu {circle} przez {author}",
    "{member} has been removed from {circle} by {author}" : "{member} został usunięty z kręgu {circle} przez {author}",
    "You removed {external} from {circle}" : "Usunąłeś {external} z kręgu {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} został usunięty z kręgu {circle} przez {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Anulowałeś zaproszenie {member} o dołączenie do kręgu {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Twoje zaproszenie o dołączenie do kręgu {circle} zostało anulowane przez {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} anulował zaproszenie {member} o dołączenie do kręgu {circle}",
    "You dismissed {member}'s request to join {circle}" : "Odrzuciłeś prośbę {member} o dołączenie do kręgu {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Twoja prośba o dołączenie do kręgu {circle} została odrzucona przez {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Prośba {member} o dołączenie do kręgu {circle} została odrzucona przez {author}",
    "You invited {member} to join {circle}" : "Zaprosiłeś {member} do dołączenia do kręgu {circle}",
    "You have been invited to join {circle} by {author}" : "Zostałeś zaproszony do dołączenia do kręgu {circle} przez {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} został zaproszony do dołączenia do kręgu {circle} przez {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Zmieniłeś poziom użytkownika {member} w {circle} na %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} zmienił Twój poziom {circle} na %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} zmienił poziom {member} w {circle} na %1$s",
    "You sent a request to join {circle}" : "Wysłałeś prośbę o dołączenie do kręgu {circle}",
    "{member} sent a request to join {circle}" : "{member} wysłał prośbę o dołączenie do kręgu {circle}",
    "You are the new owner of {circle}" : "Jesteś nowym właścicielem {circle}",
    "{member} is the new owner of {circle}" : "{member} został nowym właścicielem {circle}",
    "On events happening in a <strong>team</strong> of which you are a member" : "O wydarzeniach w <strong>zespole</strong>, którego jesteś członkiem",
    "Any important event in a <strong>team</strong> you are moderating" : "Każde ważne wydarzenie w <strong>zespole</strong>, który moderujesz",
    "On global events happening in any <strong>team</strong>" : "O wydarzeniach globalnych w dowolnym <strong>zespole</strong>",
    "Single" : "Jednoosobowy",
    "Personal" : "Osobisty",
    "System" : "System",
    "Visible" : "Widoczny",
    "Open" : "Otwórz",
    "Invite" : "Zaproś",
    "Join request" : "Prośba o dołączenie",
    "Friends" : "Przyjaciele",
    "Password protected" : "Zabezpieczone hasłem",
    "No Owner" : "Brak właściciela",
    "Hidden" : "Ukryty",
    "Backend" : "Zaplecze",
    "Local" : "Lokalny",
    "Root" : "Root",
    "Team invite" : "Zaproszenie do zespołu",
    "Federated" : "Sfederowany",
    "Mount point" : "Punkt montowania",
    "Nextcloud Account" : "Konto Nextcloud",
    "Nextcloud Group" : "Grupa Nextcloud",
    "Email address" : "Adres e-mail",
    "Contact" : "Kontakt",
    "Team" : "Zespół",
    "Nextcloud App" : "Aplikacja Nextcloud",
    "Teams App" : "Aplikacja Teams",
    "Admin Command Line" : "Administracyjny wiersz poleceń",
    "Member" : "Członek",
    "Moderator" : "Moderator",
    "Admin" : "Administrator",
    "Owner" : "Właściciel",
    "%s shared »%s« with you." : "%s udostępnił Tobie »%s«.",
    "%s shared »%s« with \"%s\"." : "%s udostępnił »%s« z \"%s\".",
    "%s on %s" : "%s na %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s udostępnił »%2$s«.\nPowinieneś już otrzymać oddzielną wiadomość zawierającą link do udostępnionego zasobu.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s udostępnił »%2$s«. Powinieneś już otrzymać oddzielną wiadomość zawierającą link do udostępnionego zasobu.",
    "Password to access »%1$s« shared to you by %2$s" : "Hasło dostępu do »%1$s« udostępnionego przez %2$s",
    "Password to access »%s«" : "Hasło dostępu do »%s«",
    "It is protected with the following password:" : "Zasób chroniony jest następującym hasłem:",
    "%1$s via %2$s" : "%1$s przez %2$s",
    "Click the button below to open it." : "Kliknij przycisk poniżej, aby go otworzyć.",
    "Open »%s«" : "Otwórz »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s udostępnił Tobie wiele plików.\nPowinieneś otrzymać osobną wiadomość e-mail z linkiem do nich.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s udostępnił Tobie wiele plików. Powinieneś otrzymać osobną wiadomość e-mail z linkiem do nich.",
    "Password to access files shared to you by %1$s" : "Hasło dostępu do plików udostępnionych Tobie przez %1$s",
    "Password to access files" : "Hasło dostępu do plików",
    "%s shared multiple files with \"%s\"." : "%s udostępnił wiele plików z \"%s\".",
    "%s shared multiple files with you." : "%s udostępnił Tobie wiele plików.",
    "Boot up" : "Uruchom",
    "Nextcloud Initialization" : "Inicjalizacja Nextcloud",
    "Circles App Initialization" : "Inicjalizacja aplikacji Zespołów",
    "Fresh installation status" : "Stan nowej instalacji",
    "Building Local Database" : "Tworzenie lokalnej bazy danych",
    "Testing Basic Circle Creation" : "Testowanie tworzenia podstawowego zespołu",
    "Adding local users and moderators" : "Dodawanie lokalnych użytkowników i moderatorów",
    "Show all teams" : "Pokaż wszystkie zespoły",
    "Create a new team" : "Utwórz nowy zespół",
    "Files" : "Pliki",
    "This feature is not available for personal circles" : "Ta funkcja nie jest dostępna dla kręgów osobistych",
    "The team is not federated" : "Zespół nie jest sfederowany",
    "You cannot join this team" : "Nie możesz dołączyć do tego zespołu",
    "This member is not a moderator" : "Ten członek nie jest moderatorem",
    "Insufficient privileges" : "Niewystarczające uprawnienia",
    "This member does not exist" : "Ten członek nie istnieje",
    "This member is the owner of the team" : "Ten członek jest właścicielem zespołu",
    "Level cannot be changed for this type of member" : "Nie można zmienić poziomu dla tego typu członka",
    "You are already a member of this circle" : "Już jesteś członkiem tego kręgu",
    "You have been blocked from this circle" : "Zostałeś zablokowany w tym zespole",
    "The account is already a member of this circle" : "Konto jest już członkiem tego zespołu",
    "The account has already been invited into this circle" : "Konto zostało już zaproszone do tego zespołu",
    "%s (Team owned by %s)" : "%s (Zespół należący do %s)",
    "You are now a member of the Team \"%2$s\"" : "Jesteś teraz członkiem zespołu „%2$s”",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Zostałeś zaproszony przez %1$s do zespołu „%2$s”",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s wysłał prośbę o dołączenie do zespołu \"%2$s\"",
    "Accept" : "Akceptuj",
    "Refuse" : "Odrzuć",
    "Leave the team" : "Opuść zespół",
    "%s" : "%s",
    "Personal team" : "Zespół osobisty",
    "%s owned by %s" : "%s należący do %s",
    "You have no permission to create a new team" : "Nie masz uprawnień do tworzenia nowego zespołu",
    "%s shared a file with \"%s\"." : "%s udostępnił plik z \"%s\".",
    "%s shared a file with you." : "%s udostępnił Tobie plik.",
    "%1$s shared %2$s with %3$s" : "%1$s udostępnia %2$s z %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s udostępnia %2$s z \"%3$s\"",
    "Open %s" : "Otwórz %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s udostępnił Tobie niektóre treści.\nPowinieneś już otrzymać osobną wiadomość e-mail z linkiem, aby uzyskać do niego dostęp.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s udostępnił Tobie niektóre treści. Powinieneś już otrzymać osobną wiadomość e-mail z linkiem, aby uzyskać do niego dostęp.",
    "Password to access content shared with you by %1$s" : "Hasło dostępu do treści udostępnionej Tobie przez %1$s",
    "Password to access content" : "Hasło dostępu do treści",
    "This item is already shared with this team" : "Ten element został już udostępniony temu zespołowi",
    "Bring cloud-users closer together." : "Integruje użytkowników chmury.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Zespoły umożliwiają tworzenie własnych grup osób/współpracowników/przyjaciół.\nTe grupy osób mogą być następnie wykorzystywane przez dowolną inną aplikację do celów udostępniania.",
    "Failed to load teams" : "Nie udało się wczytać zespołów",
    "Try again" : "Spróbuj ponownie",
    "No teams found" : "Nie znaleziono żadnych zespołów",
    "Join or create teams to see them here." : "Dołącz lub utwórz zespoły, aby je tutaj zobaczyć.",
    "Create your first team" : "Utwórz swój pierwszy zespół",
    "Loading…" : "Wczytywanie…",
    "More teams" : "Więcej zespołów",
    "No files in here" : "Brak plików tutaj",
    "No entries found in this folder" : "Brak wpisów w tym katalogu",
    "Name" : "Nazwa",
    "Size" : "Rozmiar",
    "Modified" : "Zmodyfikowano",
    "Teams' files" : "Pliki zespołów",
    "Select team to filter by" : "Wybierz zespół, według którego chcesz filtrować",
    "Please select teams to filter by" : "Wybierz zespoły, według których chcesz filtrować",
    "No files found for the selected teams" : "Nie znaleziono plików dla wybranych zespołów",
    "Shared to Circles" : "Udostępnione dla zespołów",
    "Circle" : "Krąg"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
